# Save the current working directory.
saveWd <- getwd()

# Move to the Documents\AutoboxR directory.
setwd("~/AutoboxR")

# Load the library.
library(autobox)

# Initialize the autobox package.
autoboxInitPackage()

# Check the autobox license.
autoboxCheckLicense()

# Read the BJSALES values.
objBJSALES <- autoboxReadAsc("BJSALES.ASC")

# Print the time series.
print(objBJSALES$tsHistoricalValues)

# Run the calculation.
objBJSALES <- autoboxRun(objBJSALES)

# Print the status.
print(objBJSALES$cStatus)

# Print the results
# The selection parameter selects the values to print:
# a = Actual,
# c = Cleansed (Adjusted),
# e = Equations,
# f = Forecast,
# h = Historical,
# i = Interventions,
# r = Residual,
# s = Statistics,
# t = Fitted.
autoboxPrint(objBJSALES,selection="acefhirst")

# Plot the result.
# The selection parameter selects the values to plot:
# a = Actual,
# c = Cleansed (Adjusted),
# f = Forecast,
# h = Historical,
# i = Interventions,
# n = Retained,
# r = Residual,
# t = Fitted,
# u = Future.
autoboxPlot(objBJSALES,selection="acfhinrtu")

# Unload the autobox library.
unloadNamespace("autobox")

# Restore the working directory.
setwd(saveWd)
